# Installation
> `npm install --save @types/three`

# Summary
This package contains type definitions for three.js (https://threejs.org).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped.git/tree/master/types/three

Additional Details
 * Last updated: Tue, 15 May 2018 21:28:51 GMT
 * Dependencies: webvr-api
 * Global values: Detector, THREE

# Credits
These definitions were written by Kon <http://phyzkit.net/>, Satoru Kimura <https://github.com/gyohk>, Florent Poujol <https://github.com/florentpoujol>, SereznoKot <https://github.com/SereznoKot>, HouChunlei <https://github.com/omni360>, Ivo <https://github.com/ivoisbelongtous>, David Asmuth <https://github.com/piranha771>, Brandon Roberge,
//                 Qinsi ZHU <https://github.com/qszhusightp>, Toshiya Nakakura <https://github.com/nakakura>, Poul Kjeldager Sørensen <https://github.com/s093294>, Stefan Profanter <https://github.com/Pro>, Edmund Fokschaner <https://github.com/efokschaner>, Roelof Jooste <https://github.com/PsychoSTS>, Daniel Hritzkiv <https://github.com/dhritzkiv>, Apurva Ojas <https://github.com/apurvaojas>, Tiger Oakes <https://github.com/NotWoods>, Seth Kingsley <https://github.com/sethk>.
